Source-Changes-HG archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

[src/trunk]: src fix various typos in comments and messages.



details:   https://anonhg.NetBSD.org/src/rev/a8782a995570
branches:  trunk
changeset: 372244:a8782a995570
user:      andvar <andvar%NetBSD.org@localhost>
date:      Wed Nov 02 20:38:21 2022 +0000

description:
fix various typos in comments and messages.

diffstat:

 lib/libresolv/dst_api.c                |  20 ++++++++++----------
 libexec/httpd/CHANGES                  |   4 ++--
 sys/arch/arc/conf/MIMORI               |   4 ++--
 sys/arch/m68k/fpsp/get_op.sa           |   4 ++--
 sys/arch/powerpc/include/ofw_machdep.h |   4 ++--
 sys/dev/isa/madreg.h                   |   4 ++--
 sys/dev/isa/wbsio.c                    |   4 ++--
 sys/dev/marvell/gtmpsc.c               |   6 +++---
 sys/dev/pci/if_aq.c                    |   6 +++---
 sys/kern/vfs_syscalls.c                |   6 +++---
 10 files changed, 31 insertions(+), 31 deletions(-)

diffs (279 lines):

diff -r 5dfaa01f3832 -r a8782a995570 libexec/httpd/CHANGES
--- a/libexec/httpd/CHANGES     Wed Nov 02 18:18:44 2022 +0000
+++ b/libexec/httpd/CHANGES     Wed Nov 02 20:38:21 2022 +0000
@@ -1,4 +1,4 @@
-$NetBSD: CHANGES,v 1.53 2022/01/04 06:08:14 kim Exp $
+$NetBSD: CHANGES,v 1.54 2022/11/02 20:38:21 andvar Exp $
 
 changes in bozohttpd 20220104:
        o  remove obsolete .bzdirect handling.
@@ -376,7 +376,7 @@
        - fix a bug with chdir() 
 
 changes in bozohttpd 5.02 (20000426):
-       - .pac spport from simonb
+       - .pac support from simonb
 
 changes in bozohttpd 5.01 (20000421):
        - .swf support 
diff -r 5dfaa01f3832 -r a8782a995570 sys/arch/arc/conf/MIMORI
--- a/sys/arch/arc/conf/MIMORI  Wed Nov 02 18:18:44 2022 +0000
+++ b/sys/arch/arc/conf/MIMORI  Wed Nov 02 20:38:21 2022 +0000
@@ -1,4 +1,4 @@
-#      $NetBSD: MIMORI,v 1.75 2020/01/25 18:38:35 thorpej Exp $
+#      $NetBSD: MIMORI,v 1.76 2022/11/02 20:38:21 andvar Exp $
 #      NetBSD: GENERIC,v 1.31 2000/06/09 05:33:02 soda Exp
 #
 #      MIMORI -- My NEC RISCstation 2250 (ur)
@@ -198,7 +198,7 @@
 tqphy*         at mii? phy ?           # TDK Semiconductor PHYs
 ukphy*         at mii? phy ?           # generic unknown PHYs
 
-# SCSI bus supoort
+# SCSI bus support
 scsibus*       at scsi?
 
 #### SCSI bus devices
diff -r 5dfaa01f3832 -r a8782a995570 sys/arch/m68k/fpsp/get_op.sa
--- a/sys/arch/m68k/fpsp/get_op.sa      Wed Nov 02 18:18:44 2022 +0000
+++ b/sys/arch/m68k/fpsp/get_op.sa      Wed Nov 02 20:38:21 2022 +0000
@@ -1,4 +1,4 @@
-*      $NetBSD: get_op.sa,v 1.4 2001/12/09 01:43:13 briggs Exp $
+*      $NetBSD: get_op.sa,v 1.5 2022/11/02 20:38:22 andvar Exp $
 
 *      MOTOROLA MICROPROCESSOR & MEMORY TECHNOLOGY GROUP
 *      M68000 Hi-Performance Microprocessor Division
@@ -380,7 +380,7 @@
 
 *
 * Sets the DY_MO_FLG correctly. This is used only on if it is an
-* unuspported data type exception.  Set if dyadic.
+* unsupported data type exception.  Set if dyadic.
 *
 chk_dy_mo:
        move.w  CMDREG1B(a6),d0 
diff -r 5dfaa01f3832 -r a8782a995570 sys/arch/powerpc/include/ofw_machdep.h
--- a/sys/arch/powerpc/include/ofw_machdep.h    Wed Nov 02 18:18:44 2022 +0000
+++ b/sys/arch/powerpc/include/ofw_machdep.h    Wed Nov 02 20:38:21 2022 +0000
@@ -1,4 +1,4 @@
-/* $NetBSD: ofw_machdep.h,v 1.4 2021/03/02 02:28:45 thorpej Exp $ */
+/* $NetBSD: ofw_machdep.h,v 1.5 2022/11/02 20:38:22 andvar Exp $ */
 
 /*-
  * Copyright (c) 2021 The NetBSD Foundation, Inc.
@@ -54,7 +54,7 @@
 
 #define        OFW_MAX_TRANSLATIONS    48
 
-extern bool ofwbootcons_suppress; /* supporess OF console I/O */
+extern bool ofwbootcons_suppress; /* suppress OF console I/O */
 
 extern int ofw_chosen;         /* cached handle for "/chosen" */
 extern struct OF_translation ofw_translations[OFW_MAX_TRANSLATIONS];
diff -r 5dfaa01f3832 -r a8782a995570 sys/dev/isa/madreg.h
--- a/sys/dev/isa/madreg.h      Wed Nov 02 18:18:44 2022 +0000
+++ b/sys/dev/isa/madreg.h      Wed Nov 02 20:38:21 2022 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: madreg.h,v 1.5 1998/12/08 14:26:57 augustss Exp $      */
+/*     $NetBSD: madreg.h,v 1.6 2022/11/02 20:38:22 andvar Exp $        */
 /*
  * Copyright (c) 1996 Lennart Augustsson
  * Copyright (c) 1995 Hannu Savolainen
@@ -36,7 +36,7 @@
  */
 
 /*
- * Variations of the suppored chips.
+ * Variations of the supported chips.
  */
 
 #define MAD_NONE       0
diff -r 5dfaa01f3832 -r a8782a995570 sys/dev/isa/wbsio.c
--- a/sys/dev/isa/wbsio.c       Wed Nov 02 18:18:44 2022 +0000
+++ b/sys/dev/isa/wbsio.c       Wed Nov 02 20:38:21 2022 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: wbsio.c,v 1.28 2022/10/01 07:22:55 msaitoh Exp $       */
+/*     $NetBSD: wbsio.c,v 1.29 2022/11/02 20:38:22 andvar Exp $        */
 /*     $OpenBSD: wbsio.c,v 1.10 2015/03/14 03:38:47 jsg Exp $  */
 /*
  * Copyright (c) 2008 Mark Kettenis <kettenis%openbsd.org@localhost>
@@ -827,7 +827,7 @@
        case WBSIO_ID_NCT6779D:
                break;
        default:
-               /* WDT is not supoorted */
+               /* WDT is not supported */
                return;
        }
 
diff -r 5dfaa01f3832 -r a8782a995570 sys/dev/marvell/gtmpsc.c
--- a/sys/dev/marvell/gtmpsc.c  Wed Nov 02 18:18:44 2022 +0000
+++ b/sys/dev/marvell/gtmpsc.c  Wed Nov 02 20:38:21 2022 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: gtmpsc.c,v 1.47 2018/09/03 16:29:31 riastradh Exp $    */
+/*     $NetBSD: gtmpsc.c,v 1.48 2022/11/02 20:38:22 andvar Exp $       */
 /*
  * Copyright (c) 2009 KIYOHARA Takashi
  * All rights reserved.
@@ -29,7 +29,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: gtmpsc.c,v 1.47 2018/09/03 16:29:31 riastradh Exp $");
+__KERNEL_RCSID(0, "$NetBSD: gtmpsc.c,v 1.48 2022/11/02 20:38:22 andvar Exp $");
 
 #include "opt_kgdb.h"
 
@@ -1331,7 +1331,7 @@
 }
 
 /*
- * gtmpsc_hackinit - hacks required to supprt GTMPSC console
+ * gtmpsc_hackinit - hacks required to support GTMPSC console
  */
 STATIC int
 gtmpsc_hackinit(struct gtmpsc_softc *sc, bus_space_tag_t iot,
diff -r 5dfaa01f3832 -r a8782a995570 sys/dev/pci/if_aq.c
--- a/sys/dev/pci/if_aq.c       Wed Nov 02 18:18:44 2022 +0000
+++ b/sys/dev/pci/if_aq.c       Wed Nov 02 20:38:21 2022 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: if_aq.c,v 1.38 2022/10/21 09:29:32 riastradh Exp $     */
+/*     $NetBSD: if_aq.c,v 1.39 2022/11/02 20:38:22 andvar Exp $        */
 
 /**
  * aQuantia Corporation Network Driver
@@ -62,7 +62,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: if_aq.c,v 1.38 2022/10/21 09:29:32 riastradh Exp $");
+__KERNEL_RCSID(0, "$NetBSD: if_aq.c,v 1.39 2022/11/02 20:38:22 andvar Exp $");
 
 #ifdef _KERNEL_OPT
 #include "opt_if_aq.h"
@@ -92,7 +92,7 @@
 
 /* driver configuration */
 #define CONFIG_INTR_MODERATION_ENABLE  true    /* delayed interrupt */
-#undef CONFIG_LRO_SUPPORT                      /* no LRO not suppoted */
+#undef CONFIG_LRO_SUPPORT                      /* no LRO not supported */
 #undef CONFIG_NO_TXRX_INDEPENDENT              /* share TX/RX interrupts */
 
 #define AQ_NINTR_MAX                   (AQ_RSSQUEUE_MAX + AQ_RSSQUEUE_MAX + 1)
diff -r 5dfaa01f3832 -r a8782a995570 sys/kern/vfs_syscalls.c
--- a/sys/kern/vfs_syscalls.c   Wed Nov 02 18:18:44 2022 +0000
+++ b/sys/kern/vfs_syscalls.c   Wed Nov 02 20:38:21 2022 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: vfs_syscalls.c,v 1.555 2022/02/12 15:51:29 thorpej Exp $       */
+/*     $NetBSD: vfs_syscalls.c,v 1.556 2022/11/02 20:38:22 andvar Exp $        */
 
 /*-
  * Copyright (c) 2008, 2009, 2019, 2020 The NetBSD Foundation, Inc.
@@ -70,7 +70,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: vfs_syscalls.c,v 1.555 2022/02/12 15:51:29 thorpej Exp $");
+__KERNEL_RCSID(0, "$NetBSD: vfs_syscalls.c,v 1.556 2022/11/02 20:38:22 andvar Exp $");
 
 #ifdef _KERNEL_OPT
 #include "opt_fileassoc.h"
@@ -4575,7 +4575,7 @@
 
        /*
         * Acknowledge that directories and non-directories aren't
-        * suposed to mix.
+        * supposed to mix.
         */
        if (tvp != NULL) {
                if ((fvp->v_type == VDIR) && (tvp->v_type != VDIR)) {



Home | Main Index | Thread Index | Old Index
diff -r 5dfaa01f3832 -r a8782a995570 lib/libresolv/dst_api.c
--- a/lib/libresolv/dst_api.c   Wed Nov 02 18:18:44 2022 +0000
+++ b/lib/libresolv/dst_api.c   Wed Nov 02 20:38:21 2022 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: dst_api.c,v 1.9 2022/05/24 06:27:59 andvar Exp $       */
+/*     $NetBSD: dst_api.c,v 1.10 2022/11/02 20:38:21 andvar Exp $      */
 
 /*
  * Portions Copyright (c) 1995-1998 by Trusted Information Systems, Inc.
@@ -21,7 +21,7 @@
  * This is the only file that needs to be changed if the crypto system is
  * changed.  Exported functions are:
  * void dst_init()      Initialize the toolkit
  * int  dst_check_algorithm()   Function to determines if alg is suppored.
  * int  dst_compare_keys()      Function to compare two keys for equality.
  * int  dst_sign_data()         Incremental signing routine.
  * int  dst_verify_data()       Incremental verify routine.
@@ -40,7 +40,7 @@
 #if 0
 static const char rcsid[] = "Header: /proj/cvs/prod/libbind/dst/dst_api.c,v 1.17 2007/09/24 17:18:25 each Exp ";
 #else
-__RCSID("$NetBSD: dst_api.c,v 1.9 2022/05/24 06:27:59 andvar Exp $");
+__RCSID("$NetBSD: dst_api.c,v 1.10 2022/11/02 20:38:21 andvar Exp $");
 #endif
 
 
@@ -334,7 +334,7 @@
        DST_KEY *dg_key = NULL, *pubkey = NULL;
 
        if (!dst_check_algorithm(in_alg)) { /*%< make sure alg is available */
-               EREPORT(("%s: Algorithm %d not suppored\n", __func__, in_alg));
+               EREPORT(("%s: Algorithm %d not supported\n", __func__, in_alg));
                return (NULL);
        }
        if ((type & (DST_PUBLIC | DST_PRIVATE)) == 0) 
@@ -376,7 +376,7 @@
        if (key == NULL) 
                return (0);
        if (!dst_check_algorithm(key->dk_alg)) { /*%< make sure alg is available */
-               EREPORT(("%s: Algorithm %d not suppored\n", __func__,
+               EREPORT(("%s: Algorithm %d not supported\n", __func__,
                    key->dk_alg));
                return (UNSUPPORTED_KEYALG);
        }
@@ -659,7 +659,7 @@
                return (NULL);
        alg = (u_int8_t) rdata[DST_KEY_ALG];
        if (!dst_check_algorithm(alg)) { /*%< make sure alg is available */
-               EREPORT(("%s: Algorithm %d not suppored\n", __func__,
+               EREPORT(("%s: Algorithm %d not supported\n", __func__,
                    alg));
                return (NULL);
        }
@@ -688,7 +688,7 @@
                                                  len - start) > 0)
                        return (key_st);
        } else
-               EREPORT(("%s: unsuppored alg %d\n", __func__,
+               EREPORT(("%s: unsupported alg %d\n", __func__,
                         alg));
 
        SAFE_FREE(key_st);
@@ -718,7 +718,7 @@
                return (-1);
 
        if (!dst_check_algorithm(key->dk_alg)) { /*%< make sure alg is available */
-               EREPORT(("%s: Algorithm %d not suppored\n", __func__,
+               EREPORT(("%s: Algorithm %d not supported\n", __func__,
                    key->dk_alg));
                return (UNSUPPORTED_KEYALG);
        }
@@ -775,7 +775,7 @@
        u_char dns[2048];
 
        if (!dst_check_algorithm(alg)) { /*%< make sure alg is available */
-               EREPORT(("%s: Algorithm %d not suppored\n", __func__, alg));
+               EREPORT(("%s: Algorithm %d not supported\n", __func__, alg));
                return (NULL);
        }
 
@@ -971,7 +971,7 @@
                return (NULL);
 
        if (!dst_check_algorithm(alg)) { /*%< make sure alg is available */
-               EREPORT(("%s: Algorithm %d not suppored\n", __func__, alg));
+               EREPORT(("%s: Algorithm %d not supported\n", __func__, alg));
                return (NULL);
        }
 
@@ -21,7 +21,7 @@
  * changed.  Exported functions are:
  * void dst_init()      Initialize the toolkit
- * int  dst_check_algorithm()   Function to determines if alg is suppored.
+ * int  dst_check_algorithm()   Function to determines if alg is supported.
  * int  dst_compare_keys()      Function to compare two keys for equality.
  * int  dst_sign_data()         Incremental signing routine.